@@ -70,18 +70,18 @@ class Domoticz(IPlugin):
 		bodies = ""
 		inten = jsonInput['outcome']['entities']['body']
  		log.msg("inten :  %s" % (inten)
-		if jsonInput['outcome']['entities']['location']['body'] :
-			location = jsonInput['outcome']['entities']['location']['body']
-		else:
-			bodies = "pas de lieu"
-			location= "VIDE"
-		if jsonInput['outcome']['entities']['local_search_query']['value'] :
-			local = jsonInput['outcome']['entities']['local_search_query']['value']
-		else:
-			bodies = "pas de local_search_query"
+#		if jsonInput['outcome']['entities']['location']['body'] :
+#			location = jsonInput['outcome']['entities']['location']['body']
+#		else:
+#			bodies = "pas de lieu"
+#			location= "VIDE"
+#		if jsonInput['outcome']['entities']['local_search_query']['value'] :
+#			local = jsonInput['outcome']['entities']['local_search_query']['value']
+#		else:
+#			bodies = "pas de local_search_query"
 #
 		idex= local + " " + location +  "_"
-		log.msg("index :  %s" % (idex))		
+		log.msg("idex :  %s" % (idex))		
 #		log.msg("self.configuration_plugin['param_dz']:  %s" % (self.configuration_plugin['param_dz']))		
 		for rs in self.configuration_plugin['param_dz']:
 #			log.msg("ids  :  %s" % (rs['ids']))
